@@ -31,7 +31,6 @@ __all__ = ('Connector', 'RPCSession', 'MessageSession', 'Server',
 import asyncio
 import logging
 import time
-from contextlib import suppress
 
 from aiorpcx.curio import (
     Event, TaskGroup, TaskTimeout, CancelledError,
@@ -436,9 +435,13 @@ class BatchRequest(object):
             message, event = self._session.connection.send_batch(self.batch)
             await self._session._send_message(message)
             await event.wait()
-            self.results = event.result
+            result = event.result
+            # Can happen with cancel_pending_requests
+            if isinstance(result, CancelledError):
+                raise result
+            self.results = result
             if self._raise_errors:
-                if any(isinstance(item, Exception) for item in event.result):
+                if any(isinstance(item, Exception) for item in result):
                     raise BatchError(self)
 
 
